summaryrefslogtreecommitdiffstats
path: root/src/fetch/execexternalfetcher.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/fetch/execexternalfetcher.cpp')
-rw-r--r--src/fetch/execexternalfetcher.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/fetch/execexternalfetcher.cpp b/src/fetch/execexternalfetcher.cpp
index aecdb49..1ba084f 100644
--- a/src/fetch/execexternalfetcher.cpp
+++ b/src/fetch/execexternalfetcher.cpp
@@ -129,7 +129,7 @@ void ExecExternalFetcher::search(FetchKey key_, const TQString& value_) {
return;
}
// should KProcess::quote() be used?
// %1 gets replaced by the search value, but since the arguments are going to be split
// the search value needs to be enclosed in quotation marks
// but first check to make sure the user didn't do that already
@@ -162,12 +162,12 @@ void ExecExternalFetcher::startSearch(const TQStringList& args_) {
}
#endif
- m_process = new KProcess();
- connect(m_process, TQT_SIGNAL(receivedStdout(KProcess*, char*, int)), TQT_SLOT(slotData(KProcess*, char*, int)));
- connect(m_process, TQT_SIGNAL(receivedStderr(KProcess*, char*, int)), TQT_SLOT(slotError(KProcess*, char*, int)));
- connect(m_process, TQT_SIGNAL(processExited(KProcess*)), TQT_SLOT(slotProcessExited(KProcess*)));
+ m_process = new TDEProcess();
+ connect(m_process, TQT_SIGNAL(receivedStdout(TDEProcess*, char*, int)), TQT_SLOT(slotData(TDEProcess*, char*, int)));
+ connect(m_process, TQT_SIGNAL(receivedStderr(TDEProcess*, char*, int)), TQT_SLOT(slotError(TDEProcess*, char*, int)));
+ connect(m_process, TQT_SIGNAL(processExited(TDEProcess*)), TQT_SLOT(slotProcessExited(TDEProcess*)));
*m_process << m_path << args_;
- if(!m_process->start(KProcess::NotifyOnExit, KProcess::AllOutput)) {
+ if(!m_process->start(TDEProcess::NotifyOnExit, TDEProcess::AllOutput)) {
myDebug() << "ExecExternalFetcher::startSearch() - process failed to start" << endl;
stop();
}
@@ -188,12 +188,12 @@ void ExecExternalFetcher::stop() {
emit signalDone(this);
}
-void ExecExternalFetcher::slotData(KProcess*, char* buffer_, int len_) {
+void ExecExternalFetcher::slotData(TDEProcess*, char* buffer_, int len_) {
TQDataStream stream(m_data, IO_WriteOnly | IO_Append);
stream.writeRawBytes(buffer_, len_);
}
-void ExecExternalFetcher::slotError(KProcess*, char* buffer_, int len_) {
+void ExecExternalFetcher::slotError(TDEProcess*, char* buffer_, int len_) {
GUI::CursorSaver cs(TQt::arrowCursor);
TQString msg = TQString::fromLocal8Bit(buffer_, len_);
msg.prepend(source() + TQString::fromLatin1(": "));
@@ -204,7 +204,7 @@ void ExecExternalFetcher::slotError(KProcess*, char* buffer_, int len_) {
m_errors << msg;
}
-void ExecExternalFetcher::slotProcessExited(KProcess*) {
+void ExecExternalFetcher::slotProcessExited(TDEProcess*) {
// myDebug() << "ExecExternalFetcher::slotProcessExited()" << endl;
if(!m_process->normalExit() || m_process->exitStatus()) {
myDebug() << "ExecExternalFetcher::slotProcessExited() - "<< source() << ": process did not exit successfully" << endl;
@@ -129,7 +129,7 @@ void ExecExternalFetcher::search(FetchKey key_, const TQString& value_) {
return;
}
- // should KProcess::quote() be used?
+ // should TDEProcess::quote() be used?
// %1 gets replaced by the search value, but since the arguments are going to be split
// the search value needs to be enclosed in quotation marks